@@ -189,6 +189,7 @@ class MethodsMixin:
 
     @might_commit
     @might_flush
+    @kwargs_match_entity
     @classmethod
     def edit(cls, oid=None, **kwargs):
         """Edit an object in session with the kwargs, and optionally flush or commit.
@@ -282,12 +283,10 @@ class MethodsMixin:
 
         insp = sa.inspection.inspect(cls)
 
-        skippable = lambda column: (column.key in kwargs      # skip fields already in kwargs
-                                    or column.foreign_keys    # skip foreign keys
-                                    or column.server_default  # skip fields with server defaults
-                                    or column.default         # skip fields with defaults
-                                    or column.primary_key     # skip any primary key
-                                    )
+        skippable = lambda column: (
+            column.key in kwargs                # skip fields already in kwargs
+            or cls.testing_skip_column(column)  # skip fields defined by class rules
+        )
 
         for column in (col for col in insp.columns if not skippable(col)):
             try:
@@ -298,6 +297,17 @@ class MethodsMixin:
 
         return cls.add(**kwargs)
 
+    @classmethod
+    def testing_skip_column(cls, column):
+        is_property = lambda column: isinstance(column, sa.sql.elements.Label)
+        return (
+            is_property(column)       # skip column properties
+            or column.foreign_keys    # skip foreign keys
+            or column.server_default  # skip fields with server defaults
+            or column.default         # skip fields with defaults
+            or column.primary_key     # skip any primary key
+        )
+
     @classmethod
     def random_data_for_column(cls, column, numeric_range):  # noqa: C901
         """Provides random testing data for a number of column types.
